@@ -6,10 +6,10 @@ with 'Dist::Zilla::Role::PluginBundle::Easy',
   'Dist::Zilla::Role::PluginBundle::PluginRemover';
 use namespace::clean;
 
-our $VERSION = '0.004';
+our $VERSION = '0.005';
 
 # Revisions can include entries with the standard plugin name, array ref of plugin/name/config,
-# or coderefs which are passed the pluginbundle object and return one of these formats.
+# or coderefs which are passed the pluginbundle object and return a list of plugins in one of these formats.
 my %revisions = (
   1 => [
     'GatherDir',
@@ -32,33 +32,90 @@ my %revisions = (
     'TestRelease',
     'RunExtraTests',
     'ConfirmRelease',
-    'UploadToCPAN',
+    \&_releaser,
   ],
+  2 => [
+    'GatherDir',
+    'PruneCruft',
+    'ManifestSkip',
+    'MetaConfig',
+    ['MetaProvides::Package' => { inherit_version => 0 }],
+    ['MetaNoIndex' => { directory => [qw(t xt inc share eg examples)] }],
+    'MetaYAML',
+    'MetaJSON',
+    'License',
+    'Pod2Readme',
+    \&_execdir,
+    'ShareDir',
+    'PodSyntaxTests',
+    'Test::ReportPrereqs',
+    ['Test::Compile' => { xt_mode => 1 }],
+    \&_installer,
+    'Manifest',
+    'TestRelease',
+    'RunExtraTests',
+    'ConfirmRelease',
+    \&_releaser,
+  ],
+);
+
+my %allowed_installers = (
+  MakeMaker => 1,
+  'MakeMaker::Awesome' => 1,
+  ModuleBuildTiny => 1,
+  'ModuleBuildTiny::Fallback' => 1,
+);
+
+my %option_requires = (
+  installer => 2,
 );
 
 sub configure {
   my $self = shift;
   my $revision = $self->payload->{revision};
   $revision = '1' unless defined $revision;
-  my @plugins = @{$self->get_revision($revision)};
-  foreach my $plugin (@plugins) {
-    $plugin = $plugin->($self) if ref $plugin eq 'CODE';
-    if ($ENV{FAKE_RELEASE}) {
-      if (ref $plugin eq 'ARRAY' and @$plugin and $plugin->[0] eq 'UploadToCPAN') {
-        $plugin = ['FakeRelease', @$plugin[1..$#$plugin]];
-      } elsif (!ref $plugin and $plugin eq 'UploadToCPAN') {
-        $plugin = 'FakeRelease';
-      }
-    }
-  }
-  $self->add_plugins(@plugins);
-}
-
-sub get_revision {
-  my ($self, $revision) = @_;
   die "Unknown [\@Starter] revision specified: $revision\n"
     unless exists $revisions{$revision};
-  return $revisions{$revision};
+  my @plugins = @{$revisions{$revision}};
+  
+  foreach my $option (keys %option_requires) {
+    my $required = $option_requires{$option};
+    my $value = $self->payload->{$option};
+    die "Option $option requires revision $required\n"
+      if defined $value and $required > $revision;
+  }
+  
+  foreach my $plugin (@plugins) {
+    if (ref $plugin eq 'CODE') {
+      $self->add_plugins($plugin->($self));
+    } else {
+      $self->add_plugins($plugin);
+    }
+  }
+}
+
+sub _execdir {
+  my ($self) = @_;
+  my $installer = $self->payload->{installer};
+  if (defined $installer and $installer =~ m/^ModuleBuildTiny/) {
+    return ['ExecDir' => {dir => 'script'}];
+  } else {
+    return 'ExecDir';
+  }
+}
+
+sub _installer {
+  my ($self) = @_;
+  my $installer = $self->payload->{installer};
+  return 'MakeMaker' unless defined $installer;
+  die "Unsupported installer $installer\n"
+    unless $allowed_installers{$installer};
+  return $installer;
+}
+
+sub _releaser {
+  my ($self) = @_;
+  return $ENV{FAKE_RELEASE} ? 'FakeRelease' : 'UploadToCPAN';
 }
 
 __PACKAGE__->meta->make_immutable;
@@ -75,11 +132,11 @@ Dist::Zilla::PluginBundle::Starter - A minimal Dist::Zilla plugin bundle
   author  = Example Jones <jones@example.com>
   license = Perl_5
   copyright_holder = Example Jones
-  copyright_year   = 2016
+  copyright_year   = 2017
   version = 0.001
   
   [@Starter]           ; all that is needed to start
-  revision = 1         ; always defaults to revision 1
+  revision = 2         ; always defaults to revision 1
   
   ; configuring examples
   -remove = GatherDir  ; to use [Git::GatherDir] instead, for example
@@ -124,9 +181,56 @@ Another simple way to use L<Dist::Zilla> is with L<Dist::Milla>, an opinionated
 bundle that requires no configuration and performs all of the tasks in
 L</"EXTENDING"> by default.
 
+=head1 OPTIONS
+
+C<[@Starter]> currently only has a few direct options; it can be further
+configured by the composed roles, as in L</"CONFIGURING">.
+
+=head2 revision
+
+  [@Starter]
+  revision = 2
+
+Selects the revision to use, from L</"REVISIONS">. Defaults to revision 1.
+
+=head2 installer
+
+Requires revision 2 or higher.
+
+  [@Starter]
+  revision = 2
+  installer = ModuleBuildTiny
+
+  [@Starter]
+  revision = 2
+  installer = MakeMaker::Awesome
+  MakeMaker::Awesome.WriteMakefile_arg[0] = (clean => { FILES => 't/generated/*' })
+
+The default installer is L<[MakeMaker]|Dist::Zilla::Plugin::MakeMaker>, which
+works with no extra configuration for most cases. The C<installer> option can
+be used to replace it with one of the following supported installers, which can
+then be configured in the same way as shown in L</"CONFIGURING">.
+
+L<[MakeMaker::Awesome]|Dist::Zilla::Plugin::MakeMaker::Awesome> is useful if
+you need to customize the generated F<Makefile.PL>.
+
+L<[ModuleBuildTiny]|Dist::Zilla::Plugin::ModuleBuildTiny> will generate a
+simple F<Build.PL> using L<Module::Build::Tiny>, but this may not work
+correctly with old versions of the L<CPAN>.pm installer or if you use features
+incompatible with L<Module::Build::Tiny>.
+
+L<[ModuleBuildTiny::Fallback]|Dist::Zilla::Plugin::ModuleBuildTiny::Fallback>
+generates a more complex F<Build.PL> that uses L<Module::Build::Tiny> by
+default, but falls back to L<Module::Build> on old versions of the L<CPAN>.pm
+installer that don't understand configure dependencies.
+
+When using a L<Module::Build::Tiny>-based installer, the
+L<[ExecDir]|Dist::Zilla::Plugin::ExecDir> plugin will be set to mark the
+F<script/> directory for executables instead of the default F<bin/>.
+
 =head1 REVISIONS
 
-The C<[@Starter]> plugin bundle currently includes only one revision.
+The C<[@Starter]> plugin bundle supports the following revisions.
 
 =head2 Revision 1
 
@@ -188,11 +292,24 @@ Revision 1 is the default and is equivalent to using the following plugins:
 =back
 
 This revision differs from L<[@Basic]|Dist::Zilla::PluginBundle::Basic> as
-follows: using L<[ReadmeAnyFromPod]|Dist::Zilla::Plugin::ReadmeAnyFromPod>
-instead of L<[Readme]|Dist::Zilla::Plugin::Readme>; using
-L<[RunExtraTests]|Dist::Zilla::Plugin::RunExtraTests> instead of
-L<[ExtraTests]|Dist::Zilla::Plugin::ExtraTests>; and including the following
-additional plugins: L<[MetaJSON]|Dist::Zilla::Plugin::MetaJSON>,
+follows:
+
+=over 2
+
+=item *
+
+Uses L<[ReadmeAnyFromPod]|Dist::Zilla::Plugin::ReadmeAnyFromPod>
+instead of L<[Readme]|Dist::Zilla::Plugin::Readme>.
+
+=item *
+
+Uses L<[RunExtraTests]|Dist::Zilla::Plugin::RunExtraTests> instead of
+L<[ExtraTests]|Dist::Zilla::Plugin::ExtraTests>.
+
+=item *
+
+Includes the following additional plugins:
+L<[MetaJSON]|Dist::Zilla::Plugin::MetaJSON>,
 L<[MetaConfig]|Dist::Zilla::Plugin::MetaConfig>,
 L<[MetaProvides::Package]|Dist::Zilla::Plugin::MetaProvides::Package>,
 L<[MetaNoIndex]|Dist::Zilla::Plugin::MetaNoIndex>,
@@ -200,6 +317,35 @@ L<[PodSyntaxTests]|Dist::Zilla::Plugin::PodSyntaxTests>,
 L<[Test::ReportPrereqs]|Dist::Zilla::Plugin::Test::ReportPrereqs>,
 L<[Test::Compile]|Dist::Zilla::Plugin::Test::Compile>.
 
+=back
+
+=head2 Revision 2
+
+Revision 2 is similar to Revision 1, with these differences:
+
+=over 2
+
+=item *
+
+Sets the option
+L<"inherit_version" in [MetaProvides::Package]|Dist::Zilla::Plugin::MetaProvides::Package/"inherit_version">
+to 0 by default, so that C<provides> metadata will use individual module
+versions if they differ from the distribution version.
+
+=item *
+
+L<[Pod2Readme]|Dist::Zilla::Plugin::Pod2Readme> is used instead of
+L<[ReadmeAnyFromPod]|Dist::Zilla::Plugin::ReadmeAnyFromPod> to generate the
+plaintext F<README>, as it is a simpler plugin for this purpose. It takes the
+same C<filename> and C<source_filename> options, but does not allow further
+configuration, and does not automatically use a C<.pod> file as the source.
+
+=item *
+
+The L</"installer"> option is now supported to change the installer plugin.
+
+=back
+
 =head1 CONFIGURING
 
 By using the L<PluginRemover|Dist::Zilla::Role::PluginBundle::PluginRemover> or
@@ -217,19 +363,32 @@ L<[Git::GatherDir]|Dist::Zilla::Plugin::Git::GatherDir>.
   [@Starter]
   -remove = GatherDir
 
+The included L<[GatherDir]|Dist::Zilla::Plugin::GatherDir> plugin can
+alternatively be configured directly. (See
+L<Config::MVP::Slicer/"CONFIGURATION SYNTAX"> for an explanation of the
+subscripts for slicing array attributes.)
+
+  [@Starter]
+  GatherDir.include_dotfiles = 1
+  GatherDir.exclude_filename[0] = foo_bar.txt
+  GatherDir.prune_directory[] = ^temp
+
 =head2 Readme
 
-The L<[ReadmeAnyFromPod]|Dist::Zilla::Plugin::ReadmeAnyFromPod> plugin
-generates a plaintext README from the POD text in the distribution's
-L<Dist::Zilla/"main_module"> by default, but can be configured to look
-elsewhere. The standard README should always be plaintext, but in order to
-generate a non-plaintext README in addition, the plugin can simply be used a
-second time. Note that POD-format READMEs should not be included in the
+The L<[Pod2Readme]|Dist::Zilla::Plugin::Pod2Readme> or
+L<[ReadmeAnyFromPod]|Dist::Zilla::Plugin::ReadmeAnyFromPod> plugin (depending
+on bundle revision) generates a plaintext F<README> from the POD text in the
+distribution's L<Dist::Zilla/"main_module"> by default, but can be configured
+to look elsewhere. The standard F<README> should always be plaintext, but in
+order to generate a non-plaintext F<README> in addition,
+L<[ReadmeAnyFromPod]|Dist::Zilla::Plugin::ReadmeAnyFromPod> can simply be used
+separately. Note that POD-format F<README>s should not be included in the
 distribution build because they will get indexed and installed due to an oddity
 in CPAN installation tools.
 
   [@Starter]
-  ReadmeAnyFromPod.source_filename = bin/foobar
+  revision = 2
+  Pod2Readme.source_filename = bin/foobar
   
   [ReadmeAnyFromPod / Markdown_Readme]
   type = markdown
@@ -241,7 +400,7 @@ in CPAN installation tools.
 
 =head2 ExecDir
 
-Some distributions use the C<script> directory instead of C<bin> (the
+Some distributions use the F<script/> directory instead of F<bin/> (the
 L<[ExecDir]|Dist::Zilla::Plugin::ExecDir> default) for executable scripts.
 
   [@Starter]
@@ -262,17 +421,20 @@ subscripts for slicing array attributes.)
 =head2 MetaProvides
 
 The L<[MetaProvides::Package]|Dist::Zilla::Plugin::MetaProvides::Package>
-plugin will use the distribution's version (as set in C<dist.ini> or by a
+plugin will use the distribution's version (as set in F<dist.ini> or by a
 plugin) as the version of each module when populating the C<provides> metadata
 by default. If the distribution does not have uniform module versions, the
-plugin can be configured to use each module's hardcoded version.
+plugin can be configured to reflect each module's hardcoded version where
+available, by setting the C<inherit_version> option to 0 (the default in bundle
+L</"Revision 2">).
 
   [@Starter]
-  MetaProvides::Package.inherit_version = 0
+  MetaProvides::Package.inherit_version = 0 ; default in revision 2
 
-With this option set, it will use the main distribution version as a fallback
-for any module where a version is not found. This can also be overridden, so
-that no version will be specified for these modules in the metadata.
+With this option set to 0, it will use the main distribution version as a
+fallback for any module where a version is not found. This can also be
+overridden, so that if no version is found for a module, no version will be
+specified for it in metadata, by setting C<inherit_missing> to 0 as well.
 
   [@Starter]
   MetaProvides::Package.inherit_version = 0
@@ -282,7 +444,7 @@ that no version will be specified for these modules in the metadata.
 
 This bundle includes a basic set of plugins for releasing a distribution, but
 there are many more common non-intrusive tasks that L<Dist::Zilla> can help
-with simply by using additional plugins in the C<dist.ini>.
+with simply by using additional plugins in the F<dist.ini>.
 
 =head2 Name
 
@@ -299,13 +461,19 @@ L<[LicenseFromModule]|Dist::Zilla::Plugin::LicenseFromModule>.
 
 A common approach to maintaining versions in L<Dist::Zilla>-managed
 distributions is to automatically extract the distribution's version from the
-main module, maintain uniform module versions, and bump the version after a
-release. This can be accomplished with either
-L<[RewriteVersion]|Dist::Zilla::Plugin::RewriteVersion> with
-L<[BumpVersionAfterRelease]|Dist::Zilla::Plugin::BumpVersionAfterRelease>, or
-L<[VersionFromModule]|Dist::Zilla::Plugin::VersionFromModule> with
-L<[ReversionOnRelease]|Dist::Zilla::Plugin::ReversionOnRelease>. Don't mix
-these two methods!
+main module, maintain uniform module versions, and bump the version during or
+after each release. To extract the main module version, use
+L<[RewriteVersion]|Dist::Zilla::Plugin::RewriteVersion> (which also rewrites
+your module versions to match the main module version when building) or
+L<[VersionFromMainModule]|Dist::Zilla::Plugin::VersionFromMainModule>. To
+automatically increment module versions in the repository after each release,
+use L<[BumpVersionAfterRelease]|Dist::Zilla::Plugin::BumpVersionAfterRelease>.
+Alternatively, you can use
+L<[ReversionOnRelease]|Dist::Zilla::Plugin::ReversionOnRelease> to
+automatically increment your versions in the release build, then copy the
+updated modules back to the repository with
+L<[CopyFilesFromRelease]|Dist::Zilla::Plugin::CopyFilesFromRelease>. Don't mix
+these two version increment methods!
 
 =head2 Changelog
 
